# based on https://nlp.stanford.edu/software/dependencies_manual.pdf
DEPENDENCY_DEFINITONS = {
	'acomp': 'adjectival_complement',
	'advcl': 'adverbial_clause_modifier',
	'advmod': 'adverb_modifier',
	'agent': 'agent',
	'amod': 'adjectival_modifier',
	'appos': 'appositional_modifier',
	'aux': 'auxiliary',
	'auxpass': 'passive_auxiliary',
	'cc': 'coordination',
	'ccomp': 'clausal_complement',
	'conj': 'conjunct',
	'cop': 'copula',
	'csubj': 'clausal_subject',
	'csubjpass': 'clausal_passive_subject',
	'dep': 'dependent',
	'det': 'determiner',
	'discourse': 'discourse_element',
	'dobj': 'direct_object',
	'expl': 'expletive',
	'goeswith': 'goes_with',
	'iobj': 'indirect_object',
	'mark': 'marker',
	'mwe': 'multiword_expression',
	'neg': 'negation_modifier',
	'nn': 'noun_compound_modifier',
	'npadvmod': 'noun_phrase_as_adverbial_modifier',
	'nsubj': 'nominal_subject',
	'nsubjpass': 'passive_nominal_subject',
	'num': 'numeric_modifier',
	'nummod': 'numeric_modifier',
	'number': 'element_of_compound_number',
	'parataxis': 'parataxis',
	'pcomp': 'prepositional_complement',
	'pobj': 'preposition_object',
	'poss': 'possession_modifier',
	'possessive': 'possessive_modifier',
	'preconj': 'preconjunct',
	'predet': 'predeterminer',
	'prep': 'prepositional_modifier',
	'prepc': 'prepositional_clausal_modifier',
	'prt': 'phrasal_verb_particle',
	'punct': 'punctuation',
	'quantmod': 'quantifier_phrase_modifier',
	'rcmod': 'relative_clause_modifier',
	'ref': 'referent',
	'root': 'root',
	'tmod': 'temporal_modifier',
	'vmod': 'reduced_nonfinite_verbal_modifier',
	'xcomp': 'open_clausal_complement',
	'xsubj': 'controlling_subject',
	'attr': 'attributive',
	'relcl': 'relative_clause_modifier'
}